<?php

/**

 * The Amazing Mago WordPress Plugin.

 *

 * @package   Amazing Mago

 * @author    David Farr <dave@amazingsystem.com>, Michael Carducci <michael@mago.co>

 * @license   GPL-2.0+

 * @link      https://amazingmago.co/

 * @copyright 2023 David Farr Direct LLC

 *

 * @wordpress-plugin

 * Plugin Name:      Amazing Mago

 * Plugin URI:       https://amazingmago.co/

 * Description:      Amazing Mago is the #1 Lead Generation, Client Attraction, Smart Follow-up, Show Booking & Client Retention System on the planet designed specifically for magicians & entertainers.

 * Version:          1.2.5


 * Author:           David Farr, Michael Carducci

 * Author URI:       https://support.amazingmago.co

 * Text Domain:      amazing-system

 * License:          GPL-2.0+

 * License URI:      http://www.gnu.org/licenses/gpl-2.0.txt

 * Domain Path:      /languages

 */



// Exit if accessed directly

if ( ! defined( 'ABSPATH' ) ) exit;



define( 'AMSYS_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

define( 'AMSYS_PLUGIN_FILE', __FILE__ );

define( 'AMSYS_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

define( 'AMAZINGSYSTEM_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );

define( 'AMAZINGSYSTEM_TINYMCE_JS', plugins_url( 'js/tinymce-button.js', __FILE__ ) );



//Plugin Version

define( 'AMSYS_VERSION', '1.2.4');



//Plugin Base

define( 'AMSYS_BASE', plugin_basename( __FILE__ ) );

//Use For Updating the plugin

define( 'AMSYS_REMOTE', 'http://amazingsystemtraining.com/');



//Plugin URL

define( 'AMSYS_URL', plugin_dir_url( __FILE__ ) );

//Plugin assets URL

define( 'AMSYS_ASSETS_URL', AMSYS_URL . 'assets/' );





require_once( AMSYS_PLUGIN_PATH . 'includes/amazing-system.php' );



add_filter( 'the_content', 'MagicAmazingSystemPlugin::thecontent', 1, 1);



add_action( 'plugins_loaded',      'MagicAmazingSystemPlugin::save_request_vars' );

add_action( 'init',                'MagicAmazingSystemPlugin::check_update' );

add_action( 'init',                'MagicAmazingSystemPlugin::register_shortcodes' );

add_action( 'admin_menu',          'MagicAmazingSystemPlugin::create_admin_menu' );

add_filter( 'plugin_action_links', 'MagicAmazingSystemPlugin::add_plugin_settings_link', 10, 2 );







/**

 * Register the '.php' endpoint

 *

 * 1ShoppingCart won't send POST form data to thank-you pages unless it sees '.php' or

 * '.asp' at the end of the URL. It's dumb, but we need to allow for our pages to use it.

 */

add_action( 'init', 'amazing_system_add_endpoints');

function amazing_system_add_endpoints() {

	add_rewrite_endpoint( '.php', EP_PERMALINK | EP_PAGES );

    // add_rewrite_endpoint( '1shop.asp', EP_PERMALINK | EP_PAGES );
	add_rewrite_endpoint( '?targetId=[Event.Id]', EP_PERMALINK | EP_PAGES );

}



/**

 * Prevent trailing slash redirect on our endpoint

 *

 * See previous note about 1ShoppingCart. Anyways, WordPress will try to redirect

 * `http://example.com/my-page/.php` to `http://example.com/my-page/.php/` to keep

 * the URLs looking pretty.

 *

 * When you do a redirect on a request that has POST data, you loose it. Thus we

 * need to prevent WordPress from making this redirect.

 */

add_filter('redirect_canonical', 'amsys_no_trailing_slash', 10, 2);

// function amsys_no_trailing_slash( $redirect_url, $requested_url ) {

// 	$is_our_endpoint = preg_match( '/\/(?:\.php|1shop\.asp)$/', $requested_url );

// 	$is_trailingslash_redirect = ( $redirect_url === trailingslashit( $requested_url ) ) ? true : false;

// 	if ( $is_our_endpoint && $is_trailingslash_redirect ) {

// 		// By returning false, the redirect is prevented

// 		return false;

// 	}

// 	// Not our endpoint, don't change anything

// 	return $redirect_url;

// }

function amsys_no_trailing_slash( $redirect_url, $requested_url ) {

    // Check if the requested URL contains the ?targetId= query parameter
    $is_our_endpoint = preg_match( '/\?targetId=[^&]+$/', $requested_url );

    // Check if the URL has a trailing slash
    $is_trailingslash_redirect = ( $redirect_url === trailingslashit( $requested_url ) ) ? true : false;

    // If it's our endpoint and there's a trailing slash, prevent the redirect
    if ( $is_our_endpoint && $is_trailingslash_redirect ) {
        // By returning false, the redirect is prevented
        return false;
    }

    return $redirect_url; // Return the redirect URL if no conditions match
}


/**

 * What to do when WordPress activates our plugin

 *

 * We only need to add our endpoints and flush the rules.

 */

register_activation_hook( __FILE__, 'amazing_system_installer' );

function amazing_system_installer($network) {

	global $wp_rewrite;



	MagicAmazingSystemPlugin::activated(__FILE__);

	

	amazing_system_add_endpoints();

	$wp_rewrite->flush_rules();

}

/*
* Fix shortcode use in html
*/
add_filter('wp_kses_allowed_html', 'my_kses_allowed_html', 10, 2);

function my_kses_allowed_html($allowedposttags, $context){

	$allowedposttags['input'] = array(
		'checked' => true,
		'disabled' => true,
		'name' => true,
		'type' => true,
		'value' => true,
		'class' => true,
		'id' => true,
		'style' => true,
		'title' => true,
		'role' => true,
		'placeholder'=>true,
	);


	return $allowedposttags;
}




/**

 * Run upgrade routine

 */

require AMSYS_PLUGIN_PATH . 'upgrade.php';

